==============================
NFV Orchestration Service APIs
==============================

NFV Orchestration API v1.0
--------------------------

.. toctree::
   :maxdepth: 1

   v1/legacy
   v1/vnfpkgm
   v1/vnflcm_versions
   v1/vnflcm

NFV Orchestration API v2.0
--------------------------

.. toctree::
   :maxdepth: 1

   v1/vnflcm_versions
   v2/vnflcm
